@@ -23,8 +23,8 @@ The grammer of the SPVM language is described using L<GNU Bison|https://en.wikip
   %token <opval> IF UNLESS ELSIF ELSE FOR WHILE LAST NEXT SWITCH CASE DEFAULT BREAK EVAL
   %token <opval> SYMBOL_NAME VAR_NAME CONSTANT EXCEPTION_VAR COPY_FIELDS
   %token <opval> UNDEF VOID BYTE SHORT INT LONG FLOAT DOUBLE STRING OBJECT TRUE FALSE END_OF_FILE
-  %token <opval> FATCAMMA RW RO WO INIT NEW OF BASIC_TYPE_ID EXTENDS SUPER
-  %token <opval> RETURN WEAKEN DIE WARN PRINT SAY OUTMOST_CLASS_NAME UNWEAKEN '[' '{' '('
+  %token <opval> RW RO WO INIT NEW OF BASIC_TYPE_ID EXTENDS SUPER
+  %token <opval> RETURN WEAKEN DIE WARN PRINT SAY OUTMOST_CLASS_NAME UNWEAKEN
   %type <opval> grammar
   %type <opval> field_name method_name class_name
   %type <opval> type qualified_type basic_type array_type opt_basic_type
@@ -52,7 +52,9 @@ The grammer of the SPVM language is described using L<GNU Bison|https://en.wikip
   %type <opval> array_access field_access
   %type <opval> weaken_field unweaken_field isweak_field
   %type <opval> sequential copy_fields
+  %left <opval> ',' FATCAMMA
   %right <opval> ASSIGN SPECIAL_ASSIGN
+  %right <oval> '?' ':'
   %left <opval> LOGICAL_OR DEFINED_OR
   %left <opval> LOGICAL_AND
   %left <opval> BIT_OR BIT_XOR
@@ -65,6 +67,9 @@ The grammer of the SPVM language is described using L<GNU Bison|https://en.wikip
   %right <opval> LOGICAL_NOT BIT_NOT '@' REFERENCE DEREFERENCE PLUS MINUS CONVERT SCALAR STRING_LENGTH ISWEAK TYPE_NAME COMPILE_TYPE_NAME DUMP NEW_STRING_LEN IS_READ_ONLY COPY
   %nonassoc <opval> INC DEC
   %left <opval> ARROW
+  %nonassoc <opval> ')'
+  %left <opval> '('
+  %left <opval> '[' '{'
 
   grammar
     : opt_classes
@@ -934,7 +939,9 @@ The operator precidence in the SPVM language is described using L<GNU Bison|http
 
 The bottom is the highest precidence and the top is the lowest precidence.
   
+  %left <opval> ',' FATCAMMA
   %right <opval> ASSIGN SPECIAL_ASSIGN
+  %right <oval> '?' ':'
   %left <opval> LOGICAL_OR DEFINED_OR
   %left <opval> LOGICAL_AND
   %left <opval> BIT_OR BIT_XOR
@@ -947,6 +954,9 @@ The bottom is the highest precidence and the top is the lowest precidence.
   %right <opval> LOGICAL_NOT BIT_NOT '@' REFERENCE DEREFERENCE PLUS MINUS CONVERT SCALAR STRING_LENGTH ISWEAK TYPE_NAME COMPILE_TYPE_NAME DUMP NEW_STRING_LEN IS_READ_ONLY COPY
   %nonassoc <opval> INC DEC
   %left <opval> ARROW
+  %nonassoc <opval> ')'
+  %left <opval> '('
+  %left <opval> '[' '{'
 
 The operator precidence can be increased using C<()>.
 
